==> aroundme_0_6_0.zip: aroundme_0_6_0/aroundme/language/1/barnraiser_01/sn_profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');


//HEADER
$lang['hdr_block'] = 							"block";
$lang['hdr_contact'] = 							"contact details";
$lang['hdr_relationship'] = 					"relationship";
$lang['hdr_summary'] =							"summary";
$lang['hdr_tag'] = 								"tags";
$lang['hdr_publishing'] =						"publishing";
$lang['hdr_blogs'] =							"blogs";
$lang['hdr_library_items'] =					"wiki pages";
$lang['hdr_subjects'] =							"discussions";
$lang['hdr_comments'] =							"comments";
$lang['hdr_profile'] =							"persona";


//A HREF TAGS (links)
$lang['href_unblock'] = 						"unblock this user";


//SUBMIT BUTTONS
$lang['sub_block'] = 							"block them";
$lang['sub_reveal_ts'] = 						"reveal my true self";
$lang['sub_reveal_nw'] = 						"reveal my network";
$lang['sub_invite'] = 							"send invitation";
$lang['sub_remove'] = 							"remove";


//BODY TEXT
$lang['txt_block_description_text'] = 			"If you choose to block a person you will stop them from sending you instant messages, stop them from inviting you as a new friend and stop them from seeing your profile, library and blog. You will see them listed under your blocked list. You can choose to enter a description of why you blocked them which will act as a reminder to you in the future.";
$lang['txt_item_tag'] = 						"This person has been tagged with";
$lang['txt_tag_intro'] = 						"My tags";
$lang['txt_profile'] = 							"profile"; //breadcrumb
$lang['txt_acquaintances'] = 					"acquaintances";

$lang['txt_nw_invite'] = 						"Invite into my network";
$lang['txt_is_acquaintance'] = 					"Acquaintance";
$lang['txt_is_acquaintance_intro'] = 			"You can choose to reveal your true self (or hide your true self and only show them your alias) and / or reveal your acquaintances (network) to them (or hide it so that they can only see you).";
$lang['txt_nw_invite_intro'] = 					"You can send this person an invitation to join your network. Enter a message stating who you are and why you wish for them to join your network.";
$lang['txt_nw_invite_pending'] = 				"You have invited this person into your network and they are considering your application";
$lang['txt_blocking'] = 						"Blocking";
$lang['txt_blocking_intro'] = 					"You can choose to block a user. If you do they will not be able to see your profile or message you regardless of any other ststem settings you may have.";
$lang['txt_remove_relation'] = 					"Removing acquaintance";
$lang['txt_remove_relation_intro'] = 			"You can choose to remove this acquaintance from your network list. They will be able to invite you again. If you are having a problem with them then you should block them instead.";
$lang['txt_deny_view'] = 						"Sorry, you are not allowed to see this. <a href='spl_view.php'>Login</a> to see this persons information.";

$lang["subject_im_invite"] = 					"Someone wants to add you to their network"; //used on IM send when inviting a friend

?>

==> aroundme_0_6_5.zip: aroundme_0_6_5/aroundme/language/1/barnraiser_01/sn_profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_block'] = 							"block";
$lang['hdr_contact'] = 							"contact details";
$lang['hdr_relationship'] = 					"relationship";
$lang['hdr_summary'] =							"summary";
$lang['hdr_tag'] = 								"tags";
$lang['hdr_publishing'] =						"publishing";
$lang['hdr_blogs'] =							"blogs";
$lang['hdr_library_items'] =					"wiki pages";
$lang['hdr_subjects'] =							"discussions";
$lang['hdr_comments'] =							"comments";
$lang['hdr_profile'] =							"persona";


//A HREF TAGS (links)
$lang['href_unblock'] = 						"unblock this user";


//SUBMIT BUTTONS
$lang['sub_block'] = 							"block them";
$lang['sub_reveal_ts'] = 						"reveal my true self";
$lang['sub_reveal_nw'] = 						"reveal my network";
$lang['sub_invite'] = 							"send invitation";
$lang['sub_remove'] = 							"remove";


//BODY TEXT
$lang['txt_block_description_text'] = 			"If you choose to block a person you will stop them from sending you instant messages, stop them from inviting you as a new friend and stop them from seeing your profile, library and blog. You will see them listed under your blocked list. You can choose to enter a description of why you blocked them which will act as a reminder to you in the future.";
$lang['txt_item_tag'] = 						"This person has been tagged with";
$lang['txt_tag_intro'] = 						"My tags";
$lang['txt_acquaintances'] = 					"acquaintances";

$lang['txt_nw_invite'] = 						"Invite into my network";
$lang['txt_is_acquaintance'] = 					"Acquaintance";
$lang['txt_is_acquaintance_intro'] = 			"You can choose to reveal your true self (or hide your true self and only show them your alias) and / or reveal your acquaintances (network) to them (or hide it so that they can only see you).";
$lang['txt_nw_invite_intro'] = 					"You can send this person an invitation to join your network. Enter a message stating who you are and why you wish for them to join your network.";
$lang['txt_nw_invite_pending'] = 				"You have invited this person into your network and they are considering your application";
$lang['txt_blocking'] = 						"Blocking";
$lang['txt_blocking_intro'] = 					"You can choose to block a user. If you do they will not be able to see your profile or message you regardless of any other ststem settings you may have.";
$lang['txt_remove_relation'] = 					"Removing acquaintance";
$lang['txt_remove_relation_intro'] = 			"You can choose to remove this acquaintance from your network list. They will be able to invite you again. If you are having a problem with them then you should block them instead.";
$lang['txt_deny_view'] = 						"Sorry, you are not allowed to see this. <a href='spl_view.php'>Login</a> to see this persons information.";

$lang["subject_im_invite"] = 					"Someone wants to add you to their network"; //used on IM send when inviting a friend


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"profile";

?>
